aboutsummaryrefslogtreecommitdiff
path: root/src/security/vboot/vbnv.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/security/vboot/vbnv.c')
-rw-r--r--src/security/vboot/vbnv.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/security/vboot/vbnv.c b/src/security/vboot/vbnv.c
index b99941875c..78502f74ee 100644
--- a/src/security/vboot/vbnv.c
+++ b/src/security/vboot/vbnv.c
@@ -140,11 +140,11 @@ int get_recovery_mode_from_vbnv(void)
return vbnv_data(RECOVERY_OFFSET);
}
/* Read the BOOT_OPROM_NEEDED flag from VBNV. */
int vboot_wants_oprom(void)
{
vbnv_setup();
- return (vbnv_data(BOOT_OFFSET) & BOOT_OPROM_NEEDED) ? 1 : 0;
+ return (vbnv_data(BOOT_OFFSET) & BOOT_DISPLAY_REQUEST) ? 1 : 0;
}
/* Read the USB Device Controller(UDC) enable flag from VBNV. */
@@ -140,11 +140,11 @@ int get_recovery_mode_from_vbnv(void)
return vbnv_data(RECOVERY_OFFSET);
}
-/* Read the BOOT_OPROM_NEEDED flag from VBNV. */
+/* Read the BOOT_DISPLAY_REQUEST flag from VBNV. */
int vboot_wants_oprom(void)
{